@@ -75,11 +75,13 @@ JS
             me.doSignin(null, null, function(res) {
                 if (res.isSuccess()) {
 
-                    var session = me.checkSession(res.data);
-
-                    // store session data
+                    // store session
+                    var session = me.checkSession(res.data.session);
                     me.getViewModel().set('session', session);
 
+                    // store app settings
+                    me.getViewModel().set('settings', res.data.settings);
+
                     me.setLocale(session.locale, function () {
                         Ext.route.Router.resume();
                     });
@@ -264,7 +266,12 @@ JS
 
                 if (res.isSuccess()) {
 
-                    var session = me.checkSession(res.data);
+                    // store app settings
+                    me.getViewModel().set('settings', res.data.settings);
+
+                    // store session
+                    var session = me.checkSession(res.data.session);
+                    me.getViewModel().set('session', session);
 
                     // not authenticated
                     if (!session.is_authenticated) {
@@ -279,9 +286,6 @@ JS
                     // set token and disconnect
                     APP.getApplication().api.auth(session.token);
 
-                    // store session data
-                    me.getViewModel().set('session', session);
-
                     me.setLocale(session.locale, function () {
                         me.clearInterface();
 
